@@ -208,8 +208,8 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
   client = Client(api, p)
   assert type_ in ['trade_history', 'futures_funding', 'futures_klines', 'wallet_history', 'spot_klines'], 'Wrong type_: trade_history, futures_funding, futures_klines, wallet_history available'
   if aggreg is not None:
-    assert aggreg in ['1h', '1m','5m','1d','12h'], 'Wrong aggreg_: 1m, 1h available'
-    dct_cvt = {'1m': Client.KLINE_INTERVAL_1MINUTE, '5m': Client.KLINE_INTERVAL_5MINUTE, '1h':Client.KLINE_INTERVAL_1HOUR, '1d':Client.KLINE_INTERVAL_1DAY, '12h':Client.KLINE_INTERVAL_12HOUR}
+    assert aggreg in ['1h', '1m', '5m','30m', '1d','12h'], 'Wrong aggreg_: 1m, 1h available'
+    dct_cvt = {'1m': Client.KLINE_INTERVAL_1MINUTE, '5m': Client.KLINE_INTERVAL_5MINUTE, '30m': Client.KLINE_INTERVAL_30MINUTE, '1h':Client.KLINE_INTERVAL_1HOUR, '1d':Client.KLINE_INTERVAL_1DAY, '12h':Client.KLINE_INTERVAL_12HOUR}
     aggreg = dct_cvt[aggreg]
 
   output = pd.DataFrame()
@@ -341,9 +341,22 @@ def fetch_binance_ohlc(symbol = 'BTCUSDT', frequence = '1d', public_key = None,
         binance_df['low'] = binance_df['low'].astype(float)
         save_equity_daily_data(data_df = binance_df, ticker = symbol, frequence=frequence, starting_date=start_time, running_date = end_time, local_root_directory = local_root_directory)
     else :
-        filename = symbol + '_' + frequence + '_' + start_time.strftime('%d_%b_%Y') + '_' + end_time.strftime(
-            '%d_%b_%Y') + '_daily_returns.pkl'
-        binance_df = pd.read_pickle(local_root_directory + filename)
+        try :
+            filename = symbol + '_' + frequence + '_' + start_time.strftime('%d_%b_%Y') + '_' + end_time.strftime(
+                '%d_%b_%Y') + '_daily_returns.pkl'
+            binance_df = pd.read_pickle(local_root_directory + filename)
+        except Exception as e :
+            print(f'cant fetch data {e}')
+            binance_df = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time,
+                                     symbol=symbol, aggreg=frequence)
+
+            binance_df.index = pd.to_datetime(binance_df['ts'])
+            binance_df['open'] = binance_df['open'].astype(float)
+            binance_df['close'] = binance_df['close'].astype(float)
+            binance_df['high'] = binance_df['high'].astype(float)
+            binance_df['low'] = binance_df['low'].astype(float)
+            save_equity_daily_data(data_df=binance_df, ticker=symbol, frequence=frequence, starting_date=start_time,
+                                   running_date=end_time, local_root_directory=local_root_directory)
 
     return binance_df
 
